@@ -68,6 +68,7 @@
 						bool representsNumber(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsRational(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsReal(const MathStructure &vargs, bool allow_units = false) const;\
+						bool representsNonComplex(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsComplex(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsNonZero(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsEven(const MathStructure &vargs, bool allow_units = false) const;\
@@ -83,6 +84,7 @@
 						ExpressionItem *copy() const {return new x(this);} \
 						bool representsNumber(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsReal(const MathStructure &vargs, bool allow_units = false) const;\
+						bool representsNonComplex(const MathStructure &vargs, bool allow_units = false) const;\
 					};
 #define DECLARE_BUILTIN_FUNCTION_R1(x)	class x : public MathFunction { \
 					  public: \
@@ -126,6 +128,7 @@ DECLARE_BUILTIN_FUNCTION(BinomialFunction)
 
 DECLARE_BUILTIN_FUNCTION(BitXorFunction)
 DECLARE_BUILTIN_FUNCTION_B(XorFunction)
+DECLARE_BUILTIN_FUNCTION(BitCmpFunction)
 DECLARE_BUILTIN_FUNCTION_B(OddFunction)
 DECLARE_BUILTIN_FUNCTION_B(EvenFunction)
 DECLARE_BUILTIN_FUNCTION(ShiftFunction)
@@ -134,6 +137,8 @@ DECLARE_BUILTIN_FUNCTION_R(AbsFunction)
 DECLARE_BUILTIN_FUNCTION(GcdFunction)
 DECLARE_BUILTIN_FUNCTION(LcmFunction)
 DECLARE_BUILTIN_FUNCTION_R(SignumFunction)
+DECLARE_BUILTIN_FUNCTION_R(HeavisideFunction)
+DECLARE_BUILTIN_FUNCTION_R(DiracFunction)
 DECLARE_BUILTIN_FUNCTION_R(RoundFunction)
 DECLARE_BUILTIN_FUNCTION_R(FloorFunction)
 DECLARE_BUILTIN_FUNCTION_R(CeilFunction)
@@ -186,6 +191,7 @@ DECLARE_BUILTIN_FUNCTION_R1(AcoshFunction)
 DECLARE_BUILTIN_FUNCTION(AtanhFunction)
 DECLARE_BUILTIN_FUNCTION_R1(Atan2Function)
 DECLARE_BUILTIN_FUNCTION(RadiansToDefaultAngleUnitFunction)
+DECLARE_BUILTIN_FUNCTION_R2(SincFunction)
 
 DECLARE_BUILTIN_FUNCTION(ZetaFunction)
 DECLARE_BUILTIN_FUNCTION(GammaFunction)
@@ -204,8 +210,8 @@ DECLARE_BUILTIN_FUNCTION(MaxFunction)
 DECLARE_BUILTIN_FUNCTION(ModeFunction)
 DECLARE_BUILTIN_FUNCTION_RPI(RandFunction)
 
-DECLARE_BUILTIN_FUNCTION(ISODateFunction)
-DECLARE_BUILTIN_FUNCTION(LocalDateFunction)
+DECLARE_BUILTIN_FUNCTION(DateFunction)
+DECLARE_BUILTIN_FUNCTION(TimeValueFunction)
 DECLARE_BUILTIN_FUNCTION(TimestampFunction)
 DECLARE_BUILTIN_FUNCTION(TimestampToDateFunction)
 DECLARE_BUILTIN_FUNCTION(DaysFunction)
@@ -269,6 +275,18 @@ DECLARE_BUILTIN_FUNCTION(DeriveFunction)
 DECLARE_BUILTIN_FUNCTION(IntegrateFunction)
 DECLARE_BUILTIN_FUNCTION(SolveFunction)
 DECLARE_BUILTIN_FUNCTION(SolveMultipleFunction)
+DECLARE_BUILTIN_FUNCTION(DSolveFunction)
+DECLARE_BUILTIN_FUNCTION(LimitFunction)
+
+DECLARE_BUILTIN_FUNCTION_R2(liFunction)
+DECLARE_BUILTIN_FUNCTION_R2(LiFunction)
+DECLARE_BUILTIN_FUNCTION_R2(EiFunction)
+DECLARE_BUILTIN_FUNCTION_R2(SiFunction)
+DECLARE_BUILTIN_FUNCTION_R2(CiFunction)
+DECLARE_BUILTIN_FUNCTION_R2(ShiFunction)
+DECLARE_BUILTIN_FUNCTION_R2(ChiFunction)
+DECLARE_BUILTIN_FUNCTION_R2(IGammaFunction)
+DECLARE_BUILTIN_FUNCTION_R2(GammaIncFunction)
 
 DECLARE_BUILTIN_FUNCTION(PlotFunction)
 
