@@ -491,6 +491,7 @@ class MathStructure {
 		bool isInfinity() const;
 		bool isUndefined() const;
 		bool isInteger() const;
+		bool isInfinite(bool ignore_imag = true) const;
 		bool isNumber() const;
 		bool isZero() const;
 		bool isApproximatelyZero() const;
@@ -647,8 +648,8 @@ class MathStructure {
 		/** @name Functions/operators for comparisons */
 		//@{
 
-		bool equals(const MathStructure &o, bool allow_interval = false) const;
-		bool equals(const Number &o, bool allow_interval = false) const;
+		bool equals(const MathStructure &o, bool allow_interval = false, bool allow_infinity = false) const;
+		bool equals(const Number &o, bool allow_interval = false, bool allow_infinity = false) const;
 		bool equals(int i) const;
 		bool equals(Unit *u) const;
 		bool equals(Variable *v) const;
@@ -806,12 +807,14 @@ class MathStructure {
 		
 		/** @name Functions for recursive search and replace */
 		//@{
-		int contains(const MathStructure &mstruct, bool structural_only = true, bool check_variables = false, bool check_functions = false) const;
+		int contains(const MathStructure &mstruct, bool structural_only = true, bool check_variables = false, bool check_functions = false, bool loose_equals = false) const;
+		size_t countOccurrences(const MathStructure &mstruct) const;
 		int containsRepresentativeOf(const MathStructure &mstruct, bool check_variables = false, bool check_functions = false) const;
 		int containsType(StructureType mtype, bool structural_only = true, bool check_variables = false, bool check_functions = false) const;
 		int containsRepresentativeOfType(StructureType mtype, bool check_variables = false, bool check_functions = false) const;
 		int containsFunction(MathFunction *f, bool structural_only = true, bool check_variables = false, bool check_functions = false) const;
-		int containsInterval(bool structural_only = true, bool check_variables = false, bool check_functions = false, bool ignore_high_precision_interval = false) const;
+		int containsInterval(bool structural_only = true, bool check_variables = false, bool check_functions = false, bool ignore_high_precision_interval = false, bool include_interval_function = false) const;
+		int containsInfinity(bool structural_only = true, bool check_variables = false, bool check_functions = false) const;
 		bool containsOpaqueContents() const;
 		bool containsAdditionPower() const;
 		bool containsUnknowns() const;
@@ -866,6 +869,8 @@ class MathStructure {
 		void polynomialPrimpart(const MathStructure &xvar, const MathStructure &c, MathStructure &mprim, const EvaluationOptions &eo) const;
 		void polynomialUnitContentPrimpart(const MathStructure &xvar, int &munit, MathStructure &mcontent, MathStructure &mprim, const EvaluationOptions &eo) const;
 		//@}
+		
+		bool calculateLimit(const MathStructure &x_var, const MathStructure &limit, const EvaluationOptions &eo_pre, int approach_direction = 0);
 
 		bool decomposeFractions(const MathStructure &x_var, const EvaluationOptions &eo);
 		
